local mod = ...

-- Asset
mod:registerAssetId("models/Creamery1.fbx/Prefab/CreameryPart", "PREFAB_LIVESTOCK_CREAMERY")
mod:registerAssetId("models/Creamery1.fbx/Prefab/TablePart", "PREFAB_LIVESTOCK_CREAMERY_TABLE")
mod:registerAssetId("models/Creamery1.fbx/Prefab/ConstructionSteps", "PREFAB_LIVESTOCK_CREAMERY_CONSTR")



-- Attach Node Type -------------------------------------------------------------------------------------
mod:registerPrefabComponent("models/Creamery1.fbx/Prefab/TablePart", { DataType = "COMP_BUILDING_PART", BuildingPartType = "MINOR" })



-- Paths: Sales counter -------------------------------------------------------------------------------------
mod:registerAssetId("models/Creamery1.fbx/Prefab/TablePart/PATH_B_1", "PATH_CREAMERY_B1")
mod:registerAssetId("models/Creamery1.fbx/Prefab/TablePart/PATH_C_1", "PATH_CREAMERY_C1")
mod:registerAssetId("models/Creamery1.fbx/Prefab/TablePart/PATH_D_1", "PATH_CREAMERY_D1")

mod:registerPrefabComponent("models/Creamery1.fbx/Prefab/TablePart", {
    DataType = "COMP_BUILDING_PART",
    PathList = {
        {
            PathType = BUILDING_PATH_TYPE.DEFAULT,
            WayPointList = { "PATH_CREAMERY_B1" }
        },
        {
            PathType = BUILDING_PATH_TYPE.PICKUP,
            WayPointList = { "PATH_CREAMERY_C1" }
        },
        {
            PathType = BUILDING_PATH_TYPE.PICKUP,
            WayPointList = { "PATH_CREAMERY_D1" }
        },
    }
})



-- Building Asset Processor
mod:registerAssetProcessor("models/Creamery1.fbx", { DataType = "BUILDING_ASSET_PROCESSOR" })



-- Collider Platform (climbable mesh)  -------------------------------------------------------------------------------------
mod:configurePrefabFlagList("models/Creamery1.fbx/Prefab/CreameryPart", { "PLATFORM" })



-- Grounding
mod:registerPrefabComponent("models/Creamery1.fbx/Prefab/TablePart" , {DataType = "COMP_GROUNDED"})
mod:registerPrefabComponent("models/Creamery1.fbx/Prefab/CreameryPart/Attach_Minor.002" , {DataType = "COMP_GROUNDED"})

for i=1, 8, 1 do
    mod:registerPrefabComponent("models/Creamery1.fbx/Prefab/CreameryPart/Barrel." .. string.sub("000" .. i, -3) , {DataType = "COMP_GROUNDED"})
end


-- Resource Type: Creamery
mod:registerEnumValue( "RESOURCE_TYPE", "RESOURCE_TYPE_BUTTER" )



-- Resource: Butter (OVERRIDE)
mod:override({
    Id = "BV1_BUTTER",
	ResourceTypeList = { "FOOD", "RESOURCE_TYPE_BUTTER" },
    ResourceVisualPrefab = "PREFAB_RESOURCE_VISUAL_MILK"
})



-- Job -------------------------------------------------------------------------------------
mod:register({
	DataType = "JOB",
	Id = "JOB_LIVESTOCK_CREAMERY",
	JobName = "JOB_LIVESTOCK_CREAMERY_NAME",
	JobDescription = "JOB_LIVESTOCK_CREAMERY_DESC",
	IsLockedByDefault = false,
	DefaultBehavior = "BEHAVIOR_WORK",
    ProductionDelay = 50.0, -- default 30
	AssetJobProgression = "DEFAULT_JOB_PROGRESSION",
	CharacterSetup = {
		DataType = "CHARACTER_SETUP",
			RightHandObject = {
				Model = "PREFAB_TOOL_CHEESE_MAKER_SPOON", 
			},
		IdleAnimation = "IDLE"
	}
})

mod:override({
    Id = "NEWCOMER",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_LIVESTOCK_CREAMERY"
    }
})

mod:override({
    Id = "SERF",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_LIVESTOCK_CREAMERY"
    }
})

mod:override({
    Id = "COMMONER",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_LIVESTOCK_CREAMERY"
    }
})



-- Building Function: Creamery -------------------------------------------------------------------------------------

mod:register({
    DataType = "BUILDING_FUNCTION_WORKPLACE",
	Id = "BUILDING_FUNCTION_LIVESTOCK_CREAMERY",
    Name = "BUILDING_FUNCTION_LIVESTOCK_CREAMERY_NAME",
    WorkerCapacity = 2,
    RelatedJob = { 
        Job = "JOB_LIVESTOCK_CREAMERY", 
        Behavior = "BEHAVIOR_WORK"
    },
	InputInventoryCapacity = {
		{ Resource = "MILK", Quantity = 50 },
	},
    ResourceListNeeded = {
		{ Resource = "MILK", Quantity = 2 },
	},
	ResourceProduced = {
		{ Resource = "BV1_BUTTER", Quantity = 2 },
	}

})



-- Building Function: Sales Table -------------------------------------------------------------------------------------

mod:register({
    DataType = "BUILDING_FUNCTION_MARKET",
    Id = "BUILDING_FUNCTION_LIVESTOCK_CREAMERY_TABLE",
    Name = "BUILDING_FUNCTION_LIVESTOCK_CREAMERY_TABLE_NAME",
    WorkerCapacity = 1,
    RelatedJob = { 
        Job = "MARKET_TENDER", 
        Behavior = "BEHAVIOR_WORK"
    },
	TypeList = { "RESOURCE_TYPE_BUTTER" },
	IsOverrideCapacity = true,
	CapacityPerSlot = 50,
	InputInventoryCapacity = {
		{ Resource = "BV1_BUTTER", Quantity = 25 },
	},
    ResourceListNeeded = {
		{ Resource = "BV1_BUTTER", Quantity = 5 },
	},
	ResourceProduced = {
		{ Resource = "BV1_BUTTER", Quantity = 5 },
	}
})



-- Building: Creamery ------------------------------------------------------------------------------------
mod:register({
	DataType = "BUILDING", 
	Id = "BUILDING_LIVESTOCK_CREAMERY",
	Name = "BUILDING_LIVESTOCK_CREAMERY_NAME",
	Description = "BUILDING_LIVESTOCK_CREAMERY_DESC",
	BuildingType = "GENERAL",
	AssetCoreBuildingPart = "BUILDING_PART_MONUMENT_POLE",
	BuildingPartSetList = {
		{
			Name = "BUILDING_SET_LIVESTOCK_CREAMERY_1",
			BuildingPartList = { 
                "BUILDING_PART_LIVESTOCK_CREAMERY",
                "BUILDING_PART_LIVESTOCK_CREAMERY_TABLE",
            }
        }, 
	},	
	VillagerRequired = { Status = "COMMONER", Quantity = 5 },
	IsEditable = true
})



-- Building Part: Creamery -------------------------------------------------------------------------------------
mod:register({
	DataType = "BUILDING_PART",
	Id = "BUILDING_PART_LIVESTOCK_CREAMERY",
	Name = "BUILDING_PART_LIVESTOCK_CREAMERY_NAME", 
	-- Category = "CORE",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "PREFAB_LIVESTOCK_CREAMERY"
	},
	ConstructionVisual = "PREFAB_LIVESTOCK_CREAMERY_CONSTR",
	BuildingZone = { 
        ZoneEntryList = {
            { 
                Polygon = polygon.createRectangle( {8.0, 7.1}, {0.0, 0.0} ),
                Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = false } 
			}
		}
	},
	AssetBuildingFunction = "BUILDING_FUNCTION_LIVESTOCK_CREAMERY",
	Cost = {
		BuildRightTaxes = {	{ Resource = "GOLD", Quantity = 25 } },
		UpkeepCost = { { Resource = "GOLD", Quantity = 10 } },
		RessourcesNeeded = {
            { Resource = "WOOD", Quantity = 4 },
            { Resource = "STONE", Quantity = 12 },
            { Resource = "PLANK", Quantity = 8 },
		}
	}
})



-- Building Part: Sales Counter -------------------------------------------------------------------------------------
mod:register({
	DataType = "BUILDING_PART",
	Id = "BUILDING_PART_LIVESTOCK_CREAMERY_TABLE",
	Name = "BUILDING_PART_LIVESTOCK_CREAMERY_TABLE_NAME", 
	Category = "COUNTER",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "PREFAB_LIVESTOCK_CREAMERY_TABLE"
	},
	BuildingZone = { 
        ZoneEntryList = {
            { 
                Polygon = polygon.createRectangle( {2, 2}, {0.0, 0.0} ),
                Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = true } 
			}
		}
	},
	AssetBuildingFunction = "BUILDING_FUNCTION_LIVESTOCK_CREAMERY_TABLE",
	Cost = {
		BuildRightTaxes = {	{ Resource = "GOLD", Quantity = 5 } },
		UpkeepCost = { { Resource = "GOLD", Quantity = 1 } },
		RessourcesNeeded = {
            { Resource = "PLANK", Quantity = 2 }
		}
	},
	DesirabilityModifiers = { {
		Desirability = "DESIRABILITY_RESIDENTIAL",
		Type = "ADD",
		Radius = 25.0,
		Value = 0.5
	} }
})


